==> gail-0.6.tar.bz2: gail-0.6/gail/gailclistfactory.c <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gtk/gtkclist.h>
#include <gtk/gtkaccessible.h>
#include "gailclistfactory.h"
#include "gailclist.h"

static void gail_clist_factory_class_init (GailCListFactoryClass       *klass);

static AtkObject* gail_clist_factory_create_accessible (
                               GObject                              *obj);

static GType gail_clist_factory_get_accessible_type (void);

GType
gail_clist_factory_get_type ()
{
  static GType type = 0;

  if (!type) 
  {
    static const GTypeInfo tinfo =
    {
      sizeof (GailCListFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gail_clist_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GailCListFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value entry */
    };
    type = g_type_register_static (ATK_TYPE_OBJECT_FACTORY, 
                           "GailCListFactory" , &tinfo, 0);
  }

  return type;
}

static void 
gail_clist_factory_class_init (GailCListFactoryClass *klass)
{
  AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);

  class->create_accessible = gail_clist_factory_create_accessible;
  class->get_accessible_type = gail_clist_factory_get_accessible_type;
}

AtkObjectFactory*
gail_clist_factory_new ()
{
  GObject *factory;

  factory = g_object_new (GAIL_TYPE_CLIST_FACTORY, NULL);

  return ATK_OBJECT_FACTORY (factory);
} 

static AtkObject* 
gail_clist_factory_create_accessible (GObject     *obj)
{
  GtkWidget     *widget;

  g_return_val_if_fail (GTK_IS_WIDGET (obj), NULL);

  widget = GTK_WIDGET (obj);

  return gail_clist_new (widget);
}

static GType 
gail_clist_factory_get_accessible_type (void)
{
  return GAIL_TYPE_CLIST;
}

==> gail-0.9.tar.bz2: gail-0.9/gail/gailclistfactory.c <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gtk/gtkclist.h>
#include <gtk/gtkaccessible.h>
#include "gailclistfactory.h"
#include "gailclist.h"

static void gail_clist_factory_class_init (GailCListFactoryClass       *klass);

static AtkObject* gail_clist_factory_create_accessible (
                               GObject                              *obj);

static GType gail_clist_factory_get_accessible_type (void);

GType
gail_clist_factory_get_type (void)
{
  static GType type = 0;

  if (!type) 
  {
    static const GTypeInfo tinfo =
    {
      sizeof (GailCListFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gail_clist_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GailCListFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value entry */
    };
    type = g_type_register_static (ATK_TYPE_OBJECT_FACTORY, 
                           "GailCListFactory" , &tinfo, 0);
  }

  return type;
}

static void 
gail_clist_factory_class_init (GailCListFactoryClass *klass)
{
  AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);

  class->create_accessible = gail_clist_factory_create_accessible;
  class->get_accessible_type = gail_clist_factory_get_accessible_type;
}

static AtkObject* 
gail_clist_factory_create_accessible (GObject     *obj)
{
  GtkWidget     *widget;

  g_return_val_if_fail (GTK_IS_WIDGET (obj), NULL);

  widget = GTK_WIDGET (obj);

  return gail_clist_new (widget);
}

static GType 
gail_clist_factory_get_accessible_type (void)
{
  return GAIL_TYPE_CLIST;
}
